import express from 'express';
import * as http from 'http';
import * as bodyparser from 'body-parser';
import * as dotenv from 'dotenv';

dotenv.config();

if (!process.env.PORT) {
    console.log('No port');
    process.exit(1);
}

const port: number = parseInt(process.env.PORT as string, 10);

import {CommonRoutesConfig} from './src/common/common.routes.config';
// DHBW Service
import {GeneralInfoRoutes} from './src/models/dhbw-service/generalInfo.routes.config';

// Twitch Highlight Marker
import {AddHighlightRoutes} from './src/models/twitch-highlight-marker/addHighlight.routes.config';

const app: express.Application = express();
const server: http.Server = http.createServer(app);
const routes: Array<CommonRoutesConfig> = [];

// here we are adding middleware to parse all incoming requests as JSON
app.use(bodyparser.json());

// here we are adding the UserRoutes to our array,
// after sending the Express.js application object to have the routes added to our app!
routes.push(new GeneralInfoRoutes(app));
routes.push(new AddHighlightRoutes(app));

// this is a simple route to make sure everything is working properly
app.get('/', (req: express.Request, res: express.Response) => {
    res.status(200).send('Welcome to the Pluto Development REST API V2!');
});

server.listen(port, () => {
    console.log('Server listening on Port 3000');
});
