import {CommonRoutesConfig} from '../../common/common.routes.config';
import express from 'express';
import * as AddHighlightService from './addHighlights.service';
import * as dotenv from 'dotenv';

dotenv.config();

export class AddHighlightRoutes extends CommonRoutesConfig {
    constructor(app: express.Application) {
        super(app, 'AddHighlightRoutes');
    }

    configureRoutes() {
        this.app.route(`/twitch-highlight-marker/addHighlight`)
            .get((req: express.Request, res: express.Response) => {
                res.status(200).send(`GET endpoint not defined.`);
            })
            .post((req: express.Request, res: express.Response) => {
                // Check input params
                const body = req.body;

                if(body.access_key !== process.env.TWITCH_HIGHLIGHTS_ACCESS_KEY){
                    // Unauthorized, return error
                    res.type('application/json');
                    res.status(403).send('{"status": "error", "description": "Unauthorized."}');
                } else if(!body.streamer || !body.stream_id || !body.stream_game || !body.timestamp || !body.description || !body.username){
                    // Missing params, return error
                    res.type('application/json');
                    res.status(400).send('{"status": "error", "description": "Missing parameters."}');
                } else {
                    // Everything fine, return success
                    AddHighlightService.createHighlightEntry(body);

                    res.type('application/json');
                    res.status(200).send('{"status": "success", "description": ""}');
                }
            });

        return this.app;
    }
}
